@@ -1,9 +1,10 @@
 from dataclasses import dataclass
-from typing import Callable, Dict, Mapping, Optional, Type, TypeVar, Union
+from typing import Callable, Mapping, Optional, TypeVar, Union
+
+from graphql import GraphQLScalarType
 
 from strawberry.type import StrawberryType
 
-from .exceptions import ScalarAlreadyRegisteredError
 from .utils.str_converters import to_camel_case
 
 
@@ -15,10 +16,15 @@ def identity(x):
 class ScalarDefinition(StrawberryType):
     name: str
     description: Optional[str]
+    specified_by_url: Optional[str]
     serialize: Optional[Callable]
     parse_value: Optional[Callable]
     parse_literal: Optional[Callable]
 
+    # Optionally store the GraphQLScalarType instance so that we don't get
+    # duplicates
+    implementation: Optional[GraphQLScalarType] = None
+
     def copy_with(
         self, type_var_map: Mapping[TypeVar, Union[StrawberryType, type]]
     ) -> Union[StrawberryType, type]:
@@ -29,9 +35,6 @@ class ScalarDefinition(StrawberryType):
         return False
 
 
-SCALAR_REGISTRY: Dict[Type, ScalarDefinition] = {}
-
-
 class ScalarWrapper:
     _scalar_definition: ScalarDefinition
 
@@ -45,29 +48,26 @@ class ScalarWrapper:
 def _process_scalar(
     cls,
     *,
-    name: str = None,
-    description: str = None,
-    serialize: Callable = None,
-    parse_value: Callable = None,
-    parse_literal: Callable = None
+    name: Optional[str] = None,
+    description: Optional[str] = None,
+    specified_by_url: Optional[str] = None,
+    serialize: Optional[Callable] = None,
+    parse_value: Optional[Callable] = None,
+    parse_literal: Optional[Callable] = None,
 ):
 
     name = name or to_camel_case(cls.__name__)
 
-    if cls in SCALAR_REGISTRY:
-        raise ScalarAlreadyRegisteredError(name)
-
     wrapper = ScalarWrapper(cls)
     wrapper._scalar_definition = ScalarDefinition(
         name=name,
         description=description,
+        specified_by_url=specified_by_url,
         serialize=serialize,
         parse_literal=parse_literal,
         parse_value=parse_value,
     )
 
-    SCALAR_REGISTRY[cls] = wrapper._scalar_definition
-
     return wrapper
 
 
@@ -75,10 +75,11 @@ def scalar(
     cls=None,
     *,
     name: str = None,
-    description: str = None,
+    description: Optional[str] = None,
+    specified_by_url: Optional[str] = None,
     serialize: Callable = identity,
     parse_value: Optional[Callable] = None,
-    parse_literal: Optional[Callable] = None
+    parse_literal: Optional[Callable] = None,
 ):
     """Annotates a class or type as a GraphQL custom scalar.
 
@@ -114,6 +115,7 @@ def scalar(
             cls,
             name=name,
             description=description,
+            specified_by_url=specified_by_url,
             serialize=serialize,
             parse_value=parse_value,
             parse_literal=parse_literal,
