@@ -1,11 +1,14 @@
 import dataclasses
-from typing import Any, List, NamedTuple, Tuple, Type, Union
+from typing import Any, List, NamedTuple, NoReturn, Set, Tuple, Type, Union, cast
 
+from pydantic import BaseModel
+from pydantic.fields import ModelField
 from pydantic.typing import NoArgAnyCallable
 from pydantic.utils import smart_deepcopy
 
-from strawberry.arguments import UNSET, _Unset  # type: ignore
+from strawberry.arguments import UNSET, _Unset, is_unset  # type: ignore
 from strawberry.experimental.pydantic.exceptions import (
+    AutoFieldsNotInBaseModelError,
     BothDefaultAndDefaultFactoryDefinedError,
     UnregisteredTypeException,
 )
@@ -69,30 +72,65 @@ def sort_creation_fields(
     def has_default(model_field: DataclassCreationFields) -> bool:
         """Check if field has defaults."""
         return (model_field.field.default is not dataclasses.MISSING) or (
-            model_field.field.default_factory is not dataclasses.MISSING  # type: ignore
+            model_field.field.default_factory is not dataclasses.MISSING
         )
 
     return sorted(fields, key=has_default)
 
 
-def defaults_into_factory(
-    default: Union[_Unset, Any], default_factory: Union[_Unset, NoArgAnyCallable]
-) -> Union[NoArgAnyCallable, _Unset]:
+def get_default_factory_for_field(field: ModelField) -> Union[NoArgAnyCallable, _Unset]:
     """
-    Handle mutable defaults when making the dataclass by using pydantic's smart_deepcopy
+    Gets the default factory for a pydantic field.
+
+    Handles mutable defaults when making the dataclass by using pydantic's smart_deepcopy
+
     Returns optionally a NoArgAnyCallable representing a default_factory parameter
     """
-    final_factory = default_factory
-    if default is not UNSET:
-        if default_factory is not UNSET:
-            raise BothDefaultAndDefaultFactoryDefinedError(
-                default=default, default_factory=default_factory  # type: ignore
-            )
-        else:
+    default_factory = field.default_factory
+    default = field.default
 
-            def factory_func():
-                return smart_deepcopy(default)
+    has_factory = default_factory is not None and not is_unset(default_factory)
+    has_default = default is not None and not is_unset(default)
 
-            final_factory = factory_func
+    # defining both default and default_factory is not supported
 
-    return final_factory
+    if has_factory and has_default:
+        default_factory = cast(NoArgAnyCallable, default_factory)
+
+        raise BothDefaultAndDefaultFactoryDefinedError(
+            default=default, default_factory=default_factory
+        )
+
+    # if we have a default_factory, we should return it
+
+    if has_factory:
+        default_factory = cast(NoArgAnyCallable, default_factory)
+
+        return default_factory
+
+    # if we have a default, we should return it
+
+    if has_default:
+        return lambda: smart_deepcopy(default)
+
+    # if we don't have default or default_factory, but the field is not required,
+    # we should return a factory that returns None
+
+    if not field.required:
+        return lambda: None
+
+    return UNSET
+
+
+def ensure_all_auto_fields_in_pydantic(
+    model: Type[BaseModel], auto_fields: Set[str], cls_name: str
+) -> Union[NoReturn, None]:
+    # Raise error if user defined a strawberry.auto field not present in the model
+    non_existing_fields = list(auto_fields - model.__fields__.keys())
+
+    if non_existing_fields:
+        raise AutoFieldsNotInBaseModelError(
+            fields=non_existing_fields, cls_name=cls_name, model=model
+        )
+    else:
+        return None
