@@ -1,7 +1,15 @@
-from itertools import chain
-from typing import Dict, Optional, cast
+from __future__ import annotations
 
-from graphql.type import is_object_type, is_specified_directive
+from itertools import chain
+from typing import TYPE_CHECKING, Dict, Optional, cast
+
+from graphql.type import (
+    is_enum_type,
+    is_input_type,
+    is_object_type,
+    is_scalar_type,
+    is_specified_directive,
+)
 from graphql.utilities.print_schema import (
     is_defined_type,
     print_args,
@@ -9,7 +17,10 @@ from graphql.utilities.print_schema import (
     print_deprecated,
     print_description,
     print_directive,
+    print_enum,
     print_implemented_interfaces,
+    print_input_value,
+    print_scalar,
     print_schema_definition,
     print_type as original_print_type,
 )
@@ -18,7 +29,9 @@ from strawberry.field import StrawberryField
 from strawberry.schema_directive import Location, StrawberrySchemaDirective
 from strawberry.types.types import TypeDefinition
 
-from .schema import BaseSchema
+
+if TYPE_CHECKING:
+    from strawberry.schema import BaseSchema
 
 
 def print_schema_directive_params(params: Dict) -> str:
@@ -70,10 +83,12 @@ def print_fields(type_, schema: BaseSchema) -> str:
             else None
         )
 
+        args = print_args(field.args, "  ") if hasattr(field, "args") else ""
+
         fields.append(
             print_description(field, "  ", not i)
             + f"  {name}"
-            + print_args(field.args, "  ")
+            + args
             + f": {field.type}"
             + print_field_directives(strawberry_field, schema=schema)
             + print_deprecated(field.deprecation_reason)
@@ -97,10 +112,14 @@ def print_type_directives(type_, schema: BaseSchema) -> str:
     if not strawberry_type:
         return ""
 
+    allowed_locations = (
+        [Location.INPUT_OBJECT] if strawberry_type.is_input else [Location.OBJECT]
+    )
+
     directives = (
         directive
         for directive in strawberry_type.directives or []
-        if any(location in [Location.OBJECT] for location in directive.locations)
+        if any(location in allowed_locations for location in directive.locations)
     )
 
     return "".join(
@@ -119,11 +138,34 @@ def _print_object(type_, schema: BaseSchema) -> str:
     )
 
 
-def _print_type(field, schema: BaseSchema) -> str:
-    if is_object_type(field):
-        return _print_object(field, schema)
+def _print_input_object(type_, schema: BaseSchema) -> str:
+    fields = [
+        print_description(field, "  ", not i) + "  " + print_input_value(name, field)
+        for i, (name, field) in enumerate(type_.fields.items())
+    ]
+    return (
+        print_description(type_)
+        + f"input {type_.name}"
+        + print_type_directives(type_, schema)
+        + print_block(fields)
+    )
 
-    return original_print_type(field)
+
+def _print_type(type_, schema: BaseSchema) -> str:
+    # prevents us from trying to print a scalar as an input type
+    if is_scalar_type(type_):
+        return print_scalar(type_)
+
+    if is_enum_type(type_):
+        return print_enum(type_)
+
+    if is_object_type(type_):
+        return _print_object(type_, schema)
+
+    if is_input_type(type_):
+        return _print_input_object(type_, schema)
+
+    return original_print_type(type_)
 
 
 def print_schema(schema: BaseSchema) -> str:
@@ -134,12 +176,12 @@ def print_schema(schema: BaseSchema) -> str:
     )
     type_map = graphql_core_schema.type_map
 
-    types = filter(is_defined_type, map(type_map.get, sorted(type_map)))  # type: ignore
+    types = filter(is_defined_type, map(type_map.get, sorted(type_map)))
 
     return "\n\n".join(
         chain(
             filter(None, [print_schema_definition(graphql_core_schema)]),
             (print_directive(directive) for directive in directives),
-            (_print_type(type_, schema) for type_ in types),  # type: ignore
+            (_print_type(type_, schema) for type_ in types),
         )
     )
